==> hs-vte-0.12.1_3.tbz: lib/ghc-7.4.1/cabal/vte-0.12.1/register.sh <==
#!/bin/sh
echo 'name: vte
version: 0.12.1
id: vte-0.12.1-30fb6fdf39b377d09b2cbbcaf59c04a9

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the VTE library.
description: The VTE library inserts terminal capability strings into a trie, and then
             uses it to determine if data received from a pseudo-terminal is a control
             sequence or just random data. The sample program "interpret" illustrates
             more or less what the widget sees after it filters incoming data.
category: Graphics
author: Andy Stewart, Axel Simon
exposed: True
exposed-modules: Graphics.UI.Gtk.Vte.Vte
hidden-modules: Graphics.UI.Gtk.Vte.Structs
                Graphics.UI.Gtk.Vte.Types Graphics.UI.Gtk.Vte.Signals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/vte-0.12.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/vte-0.12.1
              /usr/local/lib
hs-libraries: HSvte-0.12.1
extra-libraries: vte gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0 Xext
                 Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes
                 atk-1.0 gdk_pixbuf-2.0 pangoft2-1.0 pango-1.0 m freetype fontconfig
                 gio-2.0 gobject-2.0 gthread-2.0 gmodule-2.0 glib-2.0 cairo X11
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/vte-0.0
              /usr/local/include/gtk-2.0 /usr/local/include/atk-1.0
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/pango-1.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/cairo
              /usr/local/include/glib-2.0 /usr/local/include/pixman-1
              /usr/local/include/freetype2 /usr/local/include/libpng15
includes:
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         glib-0.12.3.1-85cbbfa847e6d4009f64bf9e4957ee21
         gtk-0.12.3.1-bb799f6cbfc601b58d749d33476c453d
         pango-0.12.3-152fed3efbb178d07db4a01583547179
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/vte-0.12.1/html/vte.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/vte-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-vte-0.12.1_5.tbz: lib/ghc-7.4.2/cabal/vte-0.12.1/register.sh <==
#!/bin/sh
echo 'name: vte
version: 0.12.1
id: vte-0.12.1-e9dd8421ab432eb990ab7e321c801498

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the VTE library.
description: The VTE library inserts terminal capability strings into a trie, and then
             uses it to determine if data received from a pseudo-terminal is a control
             sequence or just random data. The sample program "interpret" illustrates
             more or less what the widget sees after it filters incoming data.
category: Graphics
author: Andy Stewart, Axel Simon
exposed: True
exposed-modules: Graphics.UI.Gtk.Vte.Vte
hidden-modules: Graphics.UI.Gtk.Vte.Structs
                Graphics.UI.Gtk.Vte.Types Graphics.UI.Gtk.Vte.Signals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/vte-0.12.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/vte-0.12.1
              /usr/local/lib
hs-libraries: HSvte-0.12.1
extra-libraries: vte gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0 Xext
                 Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes
                 atk-1.0 gdk_pixbuf-2.0 pangoft2-1.0 pango-1.0 freetype fontconfig
                 gio-2.0 gobject-2.0 glib-2.0 cairo X11
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/vte-0.0
              /usr/local/include/gtk-2.0 /usr/local/include/atk-1.0
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/pango-1.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/cairo
              /usr/local/include/glib-2.0 /usr/local/include/pixman-1
              /usr/local/include/freetype2 /usr/local/include/libpng15
includes:
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         glib-0.12.4-2696509aa1c1a77771da26d8647d44d8
         gtk-0.12.4-19f6ea5cde84c1b0aa851a75dc1f4905
         pango-0.12.4-cdcefbd659cbfc396359822d86eab665
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/vte-0.12.1/html/vte.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/vte-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
